diff --git a/drivers/common/mlx5/mlx5_common_mr.c b/drivers/common/mlx5/mlx5_common_mr.c
index 40ff9153bd8e..b383ee31683c 100644
--- a/drivers/common/mlx5/mlx5_common_mr.c
+++ b/drivers/common/mlx5/mlx5_common_mr.c
@@ -179,7 +179,7 @@ mr_btree_insert(struct mlx5_mr_btree *bt, struct mr_cache_entry *entry)
 	/* Find out the slot for insertion. */
 	if (mr_btree_lookup(bt, &idx, entry->start) != UINT32_MAX) {
 		DRV_LOG(DEBUG,
-			"abort insertion to B-tree(%p): already exist at"
+			"insertion to B-tree(%p): already exist at"
 			" idx=%u [0x%" PRIxPTR ", 0x%" PRIxPTR ") lkey=0x%x",
 			(void *)bt, idx, entry->start, entry->end, entry->lkey);
 		/* Already exist, return. */
@@ -824,7 +824,7 @@ mlx5_mr_create_primary(void *pd,
 	rte_rwlock_write_lock(&share_cache->rwlock);
 	/*
 	 * Check the address is really missing. If other thread already created
-	 * one or it is not found due to overflow, abort and return.
+	 * one or it is not found due to overflow, cancel and return.
 	 */
 	if (mlx5_mr_lookup_cache(share_cache, entry, addr) != UINT32_MAX) {
 		/*
@@ -833,7 +833,7 @@ mlx5_mr_create_primary(void *pd,
 		 * here again.
 		 */
 		mr_btree_insert(&share_cache->cache, entry);
-		DRV_LOG(DEBUG, "Found MR for %p on final lookup, abort",
+		DRV_LOG(DEBUG, "Found MR for %p on final lookup ",
 			(void *)addr);
 		rte_rwlock_write_unlock(&share_cache->rwlock);
 		rte_mcfg_mem_read_unlock();
diff --git a/drivers/net/mlx5/hws/mlx5dr_send.c b/drivers/net/mlx5/hws/mlx5dr_send.c
index e58fdeb117f7..7c6ff3f5c75b 100644
--- a/drivers/net/mlx5/hws/mlx5dr_send.c
+++ b/drivers/net/mlx5/hws/mlx5dr_send.c
@@ -15,7 +15,7 @@ mlx5dr_send_add_new_dep_wqe(struct mlx5dr_send_engine *queue)
 	return &send_sq->dep_wqe[idx];
 }
 
-void mlx5dr_send_abort_new_dep_wqe(struct mlx5dr_send_engine *queue)
+void mlx5dr_send_cancel_new_dep_wqe(struct mlx5dr_send_engine *queue)
 {
 	queue->send_ring->send_sq.head_dep_idx--;
 }
diff --git a/drivers/net/mlx5/hws/mlx5dr_send.h b/drivers/net/mlx5/hws/mlx5dr_send.h
index c1e8616f7e35..02ecf865ad6a 100644
--- a/drivers/net/mlx5/hws/mlx5dr_send.h
+++ b/drivers/net/mlx5/hws/mlx5dr_send.h
@@ -220,7 +220,7 @@ mlx5dr_uar_write64_relaxed(uint64_t val, void *addr)
 struct mlx5dr_send_ring_dep_wqe *
 mlx5dr_send_add_new_dep_wqe(struct mlx5dr_send_engine *queue);
 
-void mlx5dr_send_abort_new_dep_wqe(struct mlx5dr_send_engine *queue);
+void mlx5dr_send_cancel_new_dep_wqe(struct mlx5dr_send_engine *queue);
 
 void mlx5dr_send_all_dep_wqe(struct mlx5dr_send_engine *queue);
 
diff --git a/drivers/net/mlx5/linux/mlx5_os.c b/drivers/net/mlx5/linux/mlx5_os.c
index d8f1adfe3df0..26aed417724c 100644
--- a/drivers/net/mlx5/linux/mlx5_os.c
+++ b/drivers/net/mlx5/linux/mlx5_os.c
@@ -2384,7 +2384,7 @@ mlx5_os_pci_probe_pf(struct mlx5_common_device *cdev,
 	}
 	if (i != ns) {
 		DRV_LOG(ERR,
-			"probe of PCI device " PCI_PRI_FMT " aborted after"
+			"probe of PCI device " PCI_PRI_FMT " canceled after"
 			" encountering an error: %s",
 			owner_pci.domain, owner_pci.bus,
 			owner_pci.devid, owner_pci.function,
@@ -2484,7 +2484,7 @@ mlx5_os_pci_probe(struct mlx5_common_device *cdev,
 						   eth_da.ports[p], mkvlist);
 			if (ret) {
 				DRV_LOG(INFO, "Probe of PCI device " PCI_PRI_FMT " "
-					"aborted due to proding failure of PF %u",
+					"canceled due to proding failure of PF %u",
 					pci_dev->addr.domain, pci_dev->addr.bus,
 					pci_dev->addr.devid, pci_dev->addr.function,
 					eth_da.ports[p]);
diff --git a/drivers/net/mlx5/mlx5_rx.c b/drivers/net/mlx5/mlx5_rx.c
index 392784050f57..7505bc888a4f 100644
--- a/drivers/net/mlx5/mlx5_rx.c
+++ b/drivers/net/mlx5/mlx5_rx.c
@@ -1085,7 +1085,7 @@ mlx5_lro_update_tcp_hdr(struct rte_tcp_hdr *__rte_restrict tcp,
 		tcp->recv_ack = cqe->lro_ack_seq_num;
 		tcp->rx_win = cqe->lro_tcp_win;
 	}
-	if (cqe->lro_tcppsh_abort_dupack & MLX5_CQE_LRO_PUSH_MASK)
+	if (cqe->lro_tcppsh_dupack & MLX5_CQE_LRO_PUSH_MASK)
 		tcp->tcp_flags |= RTE_TCP_PSH_FLAG;
 	tcp->cksum = 0;
 	csum += rte_raw_cksum(tcp, (tcp->data_off >> 4) * 4);

diff --git a/drivers/common/mlx5/mlx5_prm.h b/drivers/common/mlx5/mlx5_prm.h
index 51f426c61408..fa17b8af1846 100644
--- a/drivers/common/mlx5/mlx5_prm.h
+++ b/drivers/common/mlx5/mlx5_prm.h
@@ -192,7 +192,7 @@
 /* Tunnel packet bit in the CQE. */
 #define MLX5_CQE_RX_TUNNEL_PACKET (1u << 0)
 
 /* Mask for LRO push flag in the CQE lro_tcppsh_abort_dupack field. */
 #define MLX5_CQE_LRO_PUSH_MASK 0x40
 
 /* Mask for L4 type in the CQE hdr_type_etc field. */
@@ -423,7 +423,7 @@ struct mlx5_cqe {
 	uint8_t pkt_info;
 	uint8_t rsvd0;
 	uint16_t wqe_id;
-	uint8_t lro_tcppsh_abort_dupack;
+	uint8_t lro_tcppsh_dupack;
 	uint8_t lro_min_ttl;
 	uint16_t lro_tcp_win;
 	uint32_t lro_ack_seq_num;
@@ -192,7 +192,7 @@
 #define MLX5_CQE_RX_TUNNEL_PACKET (1u << 0)
 
-/* Mask for LRO push flag in the CQE lro_tcppsh_abort_dupack field. */
+/* Mask for LRO push flag in the CQE lro_tcppsh_dupack field. */
 #define MLX5_CQE_LRO_PUSH_MASK 0x40
 
diff --git a/drivers/net/mlx5/hws/mlx5dr_rule.c b/drivers/net/mlx5/hws/mlx5dr_rule.c
index 931c68b1606d..70a779a7558b 100644
--- a/drivers/net/mlx5/hws/mlx5dr_rule.c
+++ b/drivers/net/mlx5/hws/mlx5dr_rule.c
@@ -391,7 +391,7 @@ static int mlx5dr_rule_create_hws(struct mlx5dr_rule *rule,
 	mlx5dr_rule_create_init(rule, &ste_attr, &apply, is_update);
 
 	/* Allocate dependent match WQE since rule might have dependent writes.
-	 * The queued dependent WQE can be later aborted or kept as a dependency.
+	 * The queued dependent WQE can be later canceled or kept as a dependency.
 	 * dep_wqe buffers (ctrl, data) are also reused for all STE writes.
 	 */
 	dep_wqe = mlx5dr_send_add_new_dep_wqe(queue);
@@ -413,7 +413,7 @@ static int mlx5dr_rule_create_hws(struct mlx5dr_rule *rule,
 		ret = mlx5dr_rule_alloc_action_ste(rule, attr);
 		if (ret) {
 			DR_LOG(ERR, "Failed to allocate action memory %d", ret);
-			mlx5dr_send_abort_new_dep_wqe(queue);
+			mlx5dr_send_cancel_new_dep_wqe(queue);
 			return ret;
 		}
 		/* Skip RX/TX based on the dep_wqe init */
@@ -445,8 +445,8 @@ static int mlx5dr_rule_create_hws(struct mlx5dr_rule *rule,
 			if (action_stes || apply.require_dep)
 				break;
 
-			/* Rule has no dependencies, abort dep_wqe and send WQE now */
-			mlx5dr_send_abort_new_dep_wqe(queue);
+			/* Rule has no dependencies, cancel dep_wqe and send WQE now */
+			mlx5dr_send_cancel_new_dep_wqe(queue);
 			ste_attr.wqe_tag_is_jumbo = is_jumbo;
 			ste_attr.send_attr.notify_hw = !attr->burst;
 			ste_attr.send_attr.user_data = dep_wqe->user_data;